
Installation
============

The source code can be found on `Github <https://github.com/marcelotduarte/cx_Freeze>`__.

Issue tracking on `Github <https://github.com/marcelotduarte/cx_Freeze/issues>`_.

Install by issuing the command:

  .. code-block:: console

    pip install cx_Freeze --upgrade

or download directly from `PyPI <https://pypi.org/project/cx_Freeze>`_.
